@@ -1,18 +1,55 @@
+package perltugues;
+
 =head1 NAME
 
 perltugues - pragma para programar usando portugues estruturado
 
 =cut
 
-package perltugues;
+=head1 VERSION
+
+0.1
+
+=cut
+
+=head1 SYNOPSIS
+
+use perltugues;
+
+inteiro: i, j;
+
+texto: k;
+
+inteiro: l;
+
+para i (de 1 a 100 a cada 5) {
+   escreva i, quebra de linha;
+   k = "lalala";
+   escreva k, quebra de linha;
+   escreva j, quebra de linha;
+}
+
+enquanto(i >= j){
+   escreva 'i e j => ', i, " >= ", j++, quebra de linha;
+}
+
+escreva quebra de linha; 
+
+escreva de 0 a 50 a cada 10, quebra de linha;
+
+=head1 AUTHORS
+
+Fernando Correa de Oliveira <fco@cpan.org>
+
+=cut
 
 require 5.005_62;
 use strict;
 use warnings;
 
 BEGIN {
-   $perltugues::AUTHOR  = "Fernando C. de Oliveira <smokemachine [at] cpan [dot] org>";
-   $perltugues::VERSION =  0.0.1;
+   $perltugues::AUTHOR  = "Fernando C. de Oliveira <fco\@cpan.org>";
+   $perltugues::VERSION = 0.1;
 }
 
 my $VERSION = '0.1';
